@@ -10,16 +10,19 @@ use GPS::NMEA::Handler ();
 
 use strict;
 use Carp;
+#no strict "subs";
 use vars qw($VERSION @ISA);
 
 require Exporter;
 
 @ISA = qw(GPS::Base GPS::Serial GPS::NMEA::Handler);
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$VERSION = '0.13';
 
 use FileHandle;
 
+#$|++;
+
 sub new {
     my $class = shift;
     my %param = @_;
@@ -50,11 +53,7 @@ sub parse {
     ($short_cmd = $cmd) =~ s/^\$//;
 
     print "COMMAND: $short_cmd ($line)\n" if $self->verbose;
-    if ($self->can($short_cmd)) {
-	$self->$short_cmd($line);
-    } elsif ($self->verbose) {
-	print "Can't handle $short_cmd\n";
-    } 
+    $self->$short_cmd($line);	# if $self->can($short_cmd);
     $short_cmd;
 }
 
@@ -117,7 +116,7 @@ sub nmea_data_dump {
 sub checksum {
     my ($self,$line) = @_;
     my $csum = 0;
-    $csum ^= unpack("C",(substr($line,$_,1))) for(1..length($line)-1);
+    $csum ^= unpack("C",(substr($line,$_,1))) for(1..length($line));
 
     print "Checksum: $csum\n" if $self->verbose;
     return (sprintf("%2.2X",$csum));
@@ -144,8 +143,6 @@ GPS::NMEA - Perl interface to GPS equipment using the NMEA Protocol
 
 GPS::NMEA allows the connection and use of of a GPS receiver in perl scripts.
 
-Note that latitudes and longitudes are in DMM format.
-
 =over
 
 =head1 GETTING STARTED
@@ -157,39 +154,6 @@ Note that latitudes and longitudes are in DMM format.
 =head1 BUGS
 
 
-=head1 EXAMPLES
-
-Get the position periodically:
-
-    #!/usr/bin/perl
-    use GPS::NMEA;
-    
-    my $gps = GPS::NMEA->new(Port => '/dev/cuaa0', # or COM5: or /dev/ttyS0
-    			     Baud => 4800);
-    while(1) {
-        my($ns,$lat,$ew,$lon) = $gps->get_position;
-        print "($ns,$lat,$ew,$lon)\n";
-    }
-
-Get the internal NMEA dump:
-
-    #!/usr/bin/perl
-    use GPS::NMEA;
-    use Data::Dumper;
-    
-    my $gps = GPS::NMEA->new(Port => '/dev/cuaa0', # or COM5: or /dev/ttyS0
-    			     Baud => 4800);
-    while(1) {
-        $gps->parse;
-    
-	# Dump internal NMEA data:
-        $gps->nmea_data_dump;
-    
-        # Alternative to look at the internal NMEA data:
-        require Data::Dumper;
-        print Data::Dumper->new([$gps->{NMEADATA}],[])->Indent(1)->Useqq(1)->Dump;
-    }
-    __END__
 
 =head1 AUTHOR
 
